@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 ##
 module MIME
   ##
@@ -149,11 +151,11 @@ class MIME::Types
   def type_for(filename)
     Array(filename).flat_map { |fn|
       @extension_index[fn.chomp.downcase[/\.?([^.]*?)$/, 1]]
-    }.compact.inject(:+).sort { |a, b|
+    }.compact.inject(Set.new, :+).sort { |a, b|
       a.priority_compare(b)
     }
   end
-  alias_method :of, :type_for
+  alias of type_for
 
   # Add one or more MIME::Type objects to the set of known types. If the
   # type is already known, a warning will be displayed.
@@ -169,7 +171,7 @@ class MIME::Types
         nil
       when MIME::Types
         variants = mime_type.instance_variable_get(:@type_variants)
-        add(*variants.values.inject(:+).to_a, quiet)
+        add(*variants.values.inject(Set.new, :+).to_a, quiet)
       when Array
         add(*mime_type, quiet)
       else
@@ -183,9 +185,9 @@ class MIME::Types
   # truthy value to suppress that warning.
   def add_type(type, quiet = false)
     if !quiet and @type_variants[type.simplified].include?(type)
-      MIME::Types.logger.warn <<-warning
+      MIME::Types.logger.warn <<-WARNING
 Type #{type} is already registered as a variant of #{type.simplified}.
-      warning
+      WARNING
     end
 
     add_type_variant!(type)
@@ -195,16 +197,17 @@ Type #{type} is already registered as a variant of #{type.simplified}.
   private
 
   def add_type_variant!(mime_type)
-    @type_variants[mime_type.simplified] << mime_type
+    @type_variants.add(mime_type.simplified, mime_type)
   end
 
   def reindex_extensions!(mime_type)
     return unless @type_variants[mime_type.simplified].include?(mime_type)
+
     index_extensions!(mime_type)
   end
 
   def index_extensions!(mime_type)
-    mime_type.extensions.each { |ext| @extension_index[ext] << mime_type }
+    mime_type.extensions.each { |ext| @extension_index.add(ext, mime_type) }
   end
 
   def prune_matches(matches, complete, registered)
@@ -216,7 +219,7 @@ Type #{type} is already registered as a variant of #{type.simplified}.
   def match(pattern)
     @type_variants.select { |k, _|
       k =~ pattern
-    }.values.inject(:+)
+    }.values.inject(Set.new, :+)
   end
 end
 
